@@ -74,6 +74,7 @@ ES_LINT_CONFIG = """
     "linebreak-style": "off",
     "no-nested-ternary": "off",
     "react/self-closing-comp": "warn",
+    "react/require-default-props": "off",
     "import/prefer-default-export": "off",
      "import/order": [
       "error",
@@ -86,7 +87,7 @@ ES_LINT_CONFIG = """
 """
 
 ES_LINT_IGNORE = """
-tailwindcss.config.js
+tailwind.config.js
 postcss.config.js
 """
 
